@@ -844,7 +844,9 @@ def pbdDict_bisosRoot(
     symLink('core/bsip4', 'git/bxRepos/bisos/bsip4')
     symLink('core/bsip', 'git/bxRepos/bisos/bsip4')    
     symLink('core/bpip1', 'git/bxRepos/bisos/bpip1')
-    symLink('core/bpip', 'git/bxRepos/bisos/bpip1')    
+    symLink('core/bpip', 'git/bxRepos/bisos/bpip1')
+    symLink('core/bxio', 'git/bxRepos/bisos/bxio')
+    symLink('core/bxso', 'git/bxRepos/bisos/bxso')    
     symLink('core/var', 'var/core')
     symLink('core/tmp', 'tmp')
     symLink('core/log', 'log/core')
